@@ -1,19 +1,20 @@
 import sys
 
+
 def print_info() -> None:
     print(
-        "Type annotations for boto3.AppConfig 1.17.58\n"
-        "Version:         1.17.58.0\n"
-        "Builder version: 4.6.0\n"
+        "Type annotations for boto3.AppConfig 1.17.92\n"
+        "Version:         1.17.92.post1\n"
+        "Builder version: 4.18.2\n"
         "Docs:            https://pypi.org/project/mypy-boto3-appconfig/\n"
-        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.17.58/reference/services/appconfig.html#AppConfig\n"
+        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/appconfig.html#AppConfig\n"
         "Other services:  https://pypi.org/project/boto3-stubs/\n"
         "Changelog:       https://github.com/vemel/mypy_boto3_builder/releases"
     )
 
 
 def print_version() -> None:
-    print("1.17.58.0")
+    print("1.17.92.post1")
 
 
 def main() -> None:
