@@ -1,5 +1,7 @@
 """
-Main interface for appconfig service type definitions.
+Type annotations for appconfig service type definitions.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/type_defs.html)
 
 Usage::
 
@@ -13,10 +15,16 @@ import sys
 from datetime import datetime
 from typing import IO, Dict, List, Union
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
+from .literals import (
+    DeploymentEventTypeType,
+    DeploymentStateType,
+    EnvironmentStateType,
+    GrowthTypeType,
+    ReplicateToType,
+    TriggeredByType,
+    ValidatorTypeType,
+)
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -25,29 +33,44 @@ else:
 
 __all__ = (
     "ApplicationTypeDef",
-    "ConfigurationProfileSummaryTypeDef",
-    "DeploymentEventTypeDef",
-    "DeploymentStrategyTypeDef",
-    "DeploymentSummaryTypeDef",
-    "EnvironmentTypeDef",
-    "HostedConfigurationVersionSummaryTypeDef",
-    "MonitorTypeDef",
-    "ValidatorTypeDef",
     "ApplicationsTypeDef",
+    "ConfigurationProfileSummaryTypeDef",
     "ConfigurationProfileTypeDef",
     "ConfigurationProfilesTypeDef",
     "ConfigurationTypeDef",
+    "DeploymentEventTypeDef",
     "DeploymentStrategiesTypeDef",
+    "DeploymentStrategyTypeDef",
+    "DeploymentSummaryTypeDef",
     "DeploymentTypeDef",
     "DeploymentsTypeDef",
+    "EnvironmentTypeDef",
     "EnvironmentsTypeDef",
+    "HostedConfigurationVersionSummaryTypeDef",
     "HostedConfigurationVersionTypeDef",
     "HostedConfigurationVersionsTypeDef",
+    "MonitorTypeDef",
     "ResourceTagsTypeDef",
+    "ValidatorTypeDef",
 )
 
 ApplicationTypeDef = TypedDict(
-    "ApplicationTypeDef", {"Id": str, "Name": str, "Description": str}, total=False
+    "ApplicationTypeDef",
+    {
+        "Id": str,
+        "Name": str,
+        "Description": str,
+    },
+    total=False,
+)
+
+ApplicationsTypeDef = TypedDict(
+    "ApplicationsTypeDef",
+    {
+        "Items": List["ApplicationTypeDef"],
+        "NextToken": str,
+    },
+    total=False,
 )
 
 ConfigurationProfileSummaryTypeDef = TypedDict(
@@ -57,99 +80,11 @@ ConfigurationProfileSummaryTypeDef = TypedDict(
         "Id": str,
         "Name": str,
         "LocationUri": str,
-        "ValidatorTypes": List[Literal["JSON_SCHEMA", "LAMBDA"]],
+        "ValidatorTypes": List[ValidatorTypeType],
     },
     total=False,
 )
 
-DeploymentEventTypeDef = TypedDict(
-    "DeploymentEventTypeDef",
-    {
-        "EventType": Literal[
-            "PERCENTAGE_UPDATED",
-            "ROLLBACK_STARTED",
-            "ROLLBACK_COMPLETED",
-            "BAKE_TIME_STARTED",
-            "DEPLOYMENT_STARTED",
-            "DEPLOYMENT_COMPLETED",
-        ],
-        "TriggeredBy": Literal["USER", "APPCONFIG", "CLOUDWATCH_ALARM", "INTERNAL_ERROR"],
-        "Description": str,
-        "OccurredAt": datetime,
-    },
-    total=False,
-)
-
-DeploymentStrategyTypeDef = TypedDict(
-    "DeploymentStrategyTypeDef",
-    {
-        "Id": str,
-        "Name": str,
-        "Description": str,
-        "DeploymentDurationInMinutes": int,
-        "GrowthType": Literal["LINEAR", "EXPONENTIAL"],
-        "GrowthFactor": float,
-        "FinalBakeTimeInMinutes": int,
-        "ReplicateTo": Literal["NONE", "SSM_DOCUMENT"],
-    },
-    total=False,
-)
-
-DeploymentSummaryTypeDef = TypedDict(
-    "DeploymentSummaryTypeDef",
-    {
-        "DeploymentNumber": int,
-        "ConfigurationName": str,
-        "ConfigurationVersion": str,
-        "DeploymentDurationInMinutes": int,
-        "GrowthType": Literal["LINEAR", "EXPONENTIAL"],
-        "GrowthFactor": float,
-        "FinalBakeTimeInMinutes": int,
-        "State": Literal[
-            "BAKING", "VALIDATING", "DEPLOYING", "COMPLETE", "ROLLING_BACK", "ROLLED_BACK"
-        ],
-        "PercentageComplete": float,
-        "StartedAt": datetime,
-        "CompletedAt": datetime,
-    },
-    total=False,
-)
-
-EnvironmentTypeDef = TypedDict(
-    "EnvironmentTypeDef",
-    {
-        "ApplicationId": str,
-        "Id": str,
-        "Name": str,
-        "Description": str,
-        "State": Literal["READY_FOR_DEPLOYMENT", "DEPLOYING", "ROLLING_BACK", "ROLLED_BACK"],
-        "Monitors": List["MonitorTypeDef"],
-    },
-    total=False,
-)
-
-HostedConfigurationVersionSummaryTypeDef = TypedDict(
-    "HostedConfigurationVersionSummaryTypeDef",
-    {
-        "ApplicationId": str,
-        "ConfigurationProfileId": str,
-        "VersionNumber": int,
-        "Description": str,
-        "ContentType": str,
-    },
-    total=False,
-)
-
-MonitorTypeDef = TypedDict("MonitorTypeDef", {"AlarmArn": str, "AlarmRoleArn": str}, total=False)
-
-ValidatorTypeDef = TypedDict(
-    "ValidatorTypeDef", {"Type": Literal["JSON_SCHEMA", "LAMBDA"], "Content": str}
-)
-
-ApplicationsTypeDef = TypedDict(
-    "ApplicationsTypeDef", {"Items": List["ApplicationTypeDef"], "NextToken": str}, total=False
-)
-
 ConfigurationProfileTypeDef = TypedDict(
     "ConfigurationProfileTypeDef",
     {
@@ -166,19 +101,73 @@ ConfigurationProfileTypeDef = TypedDict(
 
 ConfigurationProfilesTypeDef = TypedDict(
     "ConfigurationProfilesTypeDef",
-    {"Items": List["ConfigurationProfileSummaryTypeDef"], "NextToken": str},
+    {
+        "Items": List["ConfigurationProfileSummaryTypeDef"],
+        "NextToken": str,
+    },
     total=False,
 )
 
 ConfigurationTypeDef = TypedDict(
     "ConfigurationTypeDef",
-    {"Content": Union[bytes, IO[bytes]], "ConfigurationVersion": str, "ContentType": str},
+    {
+        "Content": Union[bytes, IO[bytes]],
+        "ConfigurationVersion": str,
+        "ContentType": str,
+    },
+    total=False,
+)
+
+DeploymentEventTypeDef = TypedDict(
+    "DeploymentEventTypeDef",
+    {
+        "EventType": DeploymentEventTypeType,
+        "TriggeredBy": TriggeredByType,
+        "Description": str,
+        "OccurredAt": datetime,
+    },
     total=False,
 )
 
 DeploymentStrategiesTypeDef = TypedDict(
     "DeploymentStrategiesTypeDef",
-    {"Items": List["DeploymentStrategyTypeDef"], "NextToken": str},
+    {
+        "Items": List["DeploymentStrategyTypeDef"],
+        "NextToken": str,
+    },
+    total=False,
+)
+
+DeploymentStrategyTypeDef = TypedDict(
+    "DeploymentStrategyTypeDef",
+    {
+        "Id": str,
+        "Name": str,
+        "Description": str,
+        "DeploymentDurationInMinutes": int,
+        "GrowthType": GrowthTypeType,
+        "GrowthFactor": float,
+        "FinalBakeTimeInMinutes": int,
+        "ReplicateTo": ReplicateToType,
+    },
+    total=False,
+)
+
+DeploymentSummaryTypeDef = TypedDict(
+    "DeploymentSummaryTypeDef",
+    {
+        "DeploymentNumber": int,
+        "ConfigurationName": str,
+        "ConfigurationVersion": str,
+        "DeploymentDurationInMinutes": int,
+        "GrowthType": GrowthTypeType,
+        "GrowthFactor": float,
+        "FinalBakeTimeInMinutes": int,
+        "State": DeploymentStateType,
+        "PercentageComplete": float,
+        "StartedAt": datetime,
+        "CompletedAt": datetime,
+    },
     total=False,
 )
 
@@ -195,12 +184,10 @@ DeploymentTypeDef = TypedDict(
         "ConfigurationVersion": str,
         "Description": str,
         "DeploymentDurationInMinutes": int,
-        "GrowthType": Literal["LINEAR", "EXPONENTIAL"],
+        "GrowthType": GrowthTypeType,
         "GrowthFactor": float,
         "FinalBakeTimeInMinutes": int,
-        "State": Literal[
-            "BAKING", "VALIDATING", "DEPLOYING", "COMPLETE", "ROLLING_BACK", "ROLLED_BACK"
-        ],
+        "State": DeploymentStateType,
         "EventLog": List["DeploymentEventTypeDef"],
         "PercentageComplete": float,
         "StartedAt": datetime,
@@ -210,11 +197,46 @@ DeploymentTypeDef = TypedDict(
 )
 
 DeploymentsTypeDef = TypedDict(
-    "DeploymentsTypeDef", {"Items": List["DeploymentSummaryTypeDef"], "NextToken": str}, total=False
+    "DeploymentsTypeDef",
+    {
+        "Items": List["DeploymentSummaryTypeDef"],
+        "NextToken": str,
+    },
+    total=False,
+)
+
+EnvironmentTypeDef = TypedDict(
+    "EnvironmentTypeDef",
+    {
+        "ApplicationId": str,
+        "Id": str,
+        "Name": str,
+        "Description": str,
+        "State": EnvironmentStateType,
+        "Monitors": List["MonitorTypeDef"],
+    },
+    total=False,
 )
 
 EnvironmentsTypeDef = TypedDict(
-    "EnvironmentsTypeDef", {"Items": List["EnvironmentTypeDef"], "NextToken": str}, total=False
+    "EnvironmentsTypeDef",
+    {
+        "Items": List["EnvironmentTypeDef"],
+        "NextToken": str,
+    },
+    total=False,
+)
+
+HostedConfigurationVersionSummaryTypeDef = TypedDict(
+    "HostedConfigurationVersionSummaryTypeDef",
+    {
+        "ApplicationId": str,
+        "ConfigurationProfileId": str,
+        "VersionNumber": int,
+        "Description": str,
+        "ContentType": str,
+    },
+    total=False,
 )
 
 HostedConfigurationVersionTypeDef = TypedDict(
@@ -232,8 +254,34 @@ HostedConfigurationVersionTypeDef = TypedDict(
 
 HostedConfigurationVersionsTypeDef = TypedDict(
     "HostedConfigurationVersionsTypeDef",
-    {"Items": List["HostedConfigurationVersionSummaryTypeDef"], "NextToken": str},
+    {
+        "Items": List["HostedConfigurationVersionSummaryTypeDef"],
+        "NextToken": str,
+    },
     total=False,
 )
 
-ResourceTagsTypeDef = TypedDict("ResourceTagsTypeDef", {"Tags": Dict[str, str]}, total=False)
+MonitorTypeDef = TypedDict(
+    "MonitorTypeDef",
+    {
+        "AlarmArn": str,
+        "AlarmRoleArn": str,
+    },
+    total=False,
+)
+
+ResourceTagsTypeDef = TypedDict(
+    "ResourceTagsTypeDef",
+    {
+        "Tags": Dict[str, str],
+    },
+    total=False,
+)
+
+ValidatorTypeDef = TypedDict(
+    "ValidatorTypeDef",
+    {
+        "Type": ValidatorTypeType,
+        "Content": str,
+    },
+)
